@@ -2,9 +2,7 @@ package Message::Passing::Filter::Encoder::Null;
 use Moose;
 use namespace::autoclean;
 
-with 'Message::Passing::Role::Filter';
-
-sub filter { $_[1] }
+extends 'Message::Passing::Filter::Null';
 
 __PACKAGE__->meta->make_immutable;
 1;
@@ -29,6 +27,8 @@ Returns message it's passed, verbatim
 
 =over
 
+=item L<Message::Passing::Filter::Null>
+
 =item L<Message::Passing>
 
 =item L<Message::Passing::Manual::Concepts>
